@@ -1,7 +1,7 @@
 ## Hierarchical clustering
 ##
 ## Created       : 18/11/02
-## Last Modified : Time-stamp: <2003-05-28 10:33:31 lucas>
+## Last Modified : Time-stamp: <2005-03-08 15:02:53 lucas>
 ##
 ## This function is a "mix" of function dist and function hclust.
 ##
@@ -16,7 +16,7 @@ hcluster <- function (x, method = "euclidean", diag = FALSE, upper = FALSE, link
   if (!is.na(pmatch(method, "euclidian"))) 
     method <- "euclidean"
   METHODS <- c("euclidean", "maximum", "manhattan", "canberra", 
-               "binary","pearson","correlation")
+               "binary","pearson","correlation","spearman")
   method <- pmatch(method, METHODS)
   if (is.na(method)) 
     stop("invalid distance method")
